@@ -235,7 +235,7 @@ List MM_RemlRcppHenDiag(VectorXd & Y, MatrixXd & X, MatrixXd & Z , List & GList
     VectorXd DiffAbs = SigmaNew-SigmaOld;
     
     crit = DiffAbs.lpNorm<Infinity>();
-    critLL = LogLik(iteration) - LogLik(iteration-1);   
+    if(iteration > 0) critLL = LogLik(iteration) - LogLik(iteration-1);   
     it ++;
     if (it == 2 ){
       SigmaNewBis = SigmaNew;
